@@ -11,6 +11,8 @@ import adafruit_logging as logging
 # This should produce an error output
 
 logger = logging.getLogger("test")
+print_logger = logging.StreamHandler()
+logger.addHandler(print_logger)
 
 logger.setLevel(logging.ERROR)
 logger.info("Info message")
@@ -18,15 +20,9 @@ logger.error("Error message")
 
 # This should produce no output
 
-null_logger = logging.getLogger(None)
-
-null_logger.setLevel(logging.ERROR)
-null_logger.info("Info message")
-null_logger.error("Error message")
-
-# This should produce no output
-
-null_logger = logging.getLogger("")
+null_logger = logging.getLogger("null")
+null_handler = logging.NullHandler()
+null_logger.addHandler(null_handler)
 
 null_logger.setLevel(logging.ERROR)
 null_logger.info("Info message")
